=======================
Nexus VXLAN Type Driver
=======================
The following list of variables are used by the nexus VXLAN type driver.
A variable's default value can be changed by adding it to the configuration
file included on the neutron-server command line. The Nexus VXLAN type driver
is only supported for VM deployments. The sample nexus configuration file is
described here, :doc:`samples/ml2-nexus-vxlan-type-driver`.

.. show-options::

   networking_cisco.nexus_vxlan_type_driver
